==> mappingkit-6.x-1.2.tar.gz: mappingkit/drupal-proxy.php <==
<?php
// $Id: drupal-proxy.php,v 1.1.2.2 2008/08/12 07:26:17 openwereld Exp $

/**
 * @file
 * Drupal proxy script. This file must be copied to the drupal install folder.
 */

ini_set('display_errors', FALSE);

require_once('./includes/bootstrap.inc');

$params = $_GET;
$url = isset($params['url']) ? $params['url'] : '';
if (empty($url)) {
  echo "Url missing";
  exit();
}

unset($params['url']);
$ch = strpos($url, '?') == FALSE ? '?' : (substr($url, -1) == '&' ? '' : '&');
foreach ($params as $key => $value) {
  $url .= "{$ch}$key=$value";
  $ch = '&';
}

if (isset($_GET['debug'])) {
  die( var_export(array($url, $_GET, $_REQUEST), true) );
}

// Minimum load of components.
drupal_bootstrap(DRUPAL_BOOTSTRAP_CONFIGURATION);

//global $user;
//die(var_export($user, true));

//require_once './includes/install.inc';
require_once './includes/common.inc';
//require_once './modules/system/system.install';

//echo function_exists('drupal_http_request');
//global $user;
//echo var_export($user, true);

/*
// Load module basics.
include_once './includes/module.inc';
$module_list['system']['filename'] = 'modules/system/system.module';
$module_list['filter']['filename'] = 'modules/filter/filter.module';
module_list(TRUE, FALSE, FALSE, $module_list);
drupal_load('module', 'system');
drupal_load('module', 'filter');
*/
//echo var_export(function_exists('drupal_http_request'), true);

$response = drupal_http_request($url);
if ($response->error) {
  header('HTTP/1.1 404 Not Found');
  echo var_export($response, true);
}
else {
  if (isset($response->headers)) {
    foreach ($response->headers as $key => $value) {
      drupal_set_header("$key: $value");
    }
  }
  echo $response->data;
}
exit();

==> mappingkit-6.x-1.4.tar.gz: mappingkit/drupal-proxy.php <==
<?php
// $Id: drupal-proxy.php,v 1.1.2.3 2009/01/26 22:13:37 openwereld Exp $

/**
 * @file
 * Drupal proxy script. This file must be copied to the drupal install folder.
 */

ini_set('display_errors', FALSE);

require_once('./includes/bootstrap.inc');

$params = $_GET;
$url = isset($params['url']) ? $params['url'] : '';
if (empty($url)) {
  echo "Url missing";
  exit();
}

unset($params['url']);
$ch = strpos($url, '?') == FALSE ? '?' : (substr($url, -1) == '&' ? '' : '&');
foreach ($params as $key => $value) {
  $url .= "{$ch}$key=" . urlencode($value);
  $ch = '&';
}

// Minimum load of components.
drupal_bootstrap(DRUPAL_BOOTSTRAP_CONFIGURATION);

//global $user;

//require_once './includes/install.inc';
require_once './includes/common.inc';
//require_once './modules/system/system.install';

/*
// Load module basics.
include_once './includes/module.inc';
$module_list['system']['filename'] = 'modules/system/system.module';
$module_list['filter']['filename'] = 'modules/filter/filter.module';
module_list(TRUE, FALSE, FALSE, $module_list);
drupal_load('module', 'system');
drupal_load('module', 'filter');
*/

// Proxy request should pass on cookie headers to prevent Drupal from
// ending a session. Note: only if same host as this site!
$headers = array();
if (!empty($_COOKIE) && $_SERVER['HTTP_HOST'] == parse_url($url, PHP_URL_HOST)) {
  $cookies = ''; $ch = '';
  foreach ($_COOKIE as $key => $value) {
    $cookies .= $ch . $key . '=' . $value;
    $ch = '; ';
  }
  $headers['Cookie'] = $cookies;
}

$response = drupal_http_request($url, $headers);
if ($response->error) {
  header('HTTP/1.1 404 Not Found');
  echo var_export($response, true);
}
else {
  if (isset($response->headers)) {
    foreach ($response->headers as $key => $value) {
      drupal_set_header("$key: $value");
    }
  }
  echo $response->data;
}
exit();
